Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/dht_simpletest.py
    :caption: examples/dht_simpletest.py
    :linenos:


DHT to Led Display
------------------

Example of reading temperature and humidity from a DHT device
and displaying results to the serial port and a 8 digit 7-segment display

.. literalinclude:: ../examples/dht_to_led_display.py
    :caption: examples/dht_to_led_display.py
    :linenos:


Time calibration advance test
------------------------------

Example to identify best waiting time for the sensor

.. literalinclude:: ../examples/dht_time_calibration_advance.py
    :caption: examples/dht_time_calibration_advance.py
    :linenos:
